

REM arguments passed by OSTRICH:
REM     rank      – The zero-based processor id of the processor that invoked the script.
REM     trial     – For multi-start algorithms (i.e. DDSAU, MS-GML, and PSO-GML) the trial
REM                 argument indicates which multi-start trial is currently underway.
REM                 For all other algorithms the trial argument is set to 0.
REM     counter   – The current count of model runs completed for the given rank and trial.
REM     objective function category (ofcat) – A text string that categorizes the objective
REM                 function value associated with the completed model run. User-defined model
REM                 preservation scripts may wish to take different actions depending on the
REM                 ofcat setting. Possible values are given below:
REM                 - best           – For single-objective algorithms, an ofcat
REM                                    value of "best" indicates that the completed
REM                                    model run is the best solution obtained so far.
REM                 - behavioral     – For uncertainty-based algorithms, an ofcat
REM                                    value of "behavioral" indicates that the completed
REM                                    model run is a behavioral solution.
REM                 - non-behavioral – For uncertainty-based algorithms, an ofcat value
REM                                    of "non- behavioral" indicates that the completed
REM                                    model run is a non-behavioral solution.
REM                 - dominated      – For multi-objective algorithms, an ofcat value of
REM                                    "dominated" indicates that the completed model run
REM                                    is a dominated solution.
REM                 - non-dominated  – For multi-objective algorithms, an ofcat value of
REM                                    "non- dominated" indicates that the completed model
REM                                    run is a non-dominated solution based on the model
REM                                    runs that have completed so far. Note that a non-
REM                                    dominated solution may become dominated later in a
REM                                    search.
REM                 - other          – An ofcat value of "other" indicates that the completed
REM                                    model run does not fit into any of the previously
REM                                    listed categories. For example, in a single-objective
REM                                    algorithm this would indicate that the completed model
REM                                    run is not the best solution obtained so far.



set filename="Solution_%~3"

if EXIST %filename% rmdir /s /q %filename%

mkdir %filename%

copy model\output\LOWRL_Diagnostics.csv %filename%\LOWRL_Diagnostics.csv
copy model\output\LOWRL_Hydrographs.csv %filename%\LOWRL_Hydrographs.csv
copy model\LOWRL.rvp %filename%\LOWRL.rvp
copy model\LOWRL.rvh %filename%\LOWRL.rvh

copy model\Reservoir_Lac_La_Croix.rvh %filename%\Reservoir_Lac_La_Croix.rvh
copy model\Reservoir_LOW.rvh %filename%\Reservoir_LOW.rvh
copy model\Reservoir_Nam.rvh %filename%\Reservoir_Nam.rvh
copy model\Reservoir_Rainy.rvh %filename%\Reservoir_Rainy.rvh
copy model\Reservoir_Blindfold.rvh %filename%\Reservoir_BlindFold.rvh
copy model\Reservoir_DryBerry.rvh %filename%\Reservoir_DryBerry.rvh
copy model\Reservoir_Berry.rvh %filename%\Reservoir_Berry.rvh
copy model\Reservoir_Atikwa.rvh %filename%\Reservoir_Atikwa.rvh
copy model\Reservoir_DogPaw.rvh %filename%\Reservoir_DogPaw.rvh
copy model\Reservoir_Kakagi.rvh %filename%\Reservoir_Kakagi.rvh
copy model\Reservoir_Rowan.rvh %filename%\Reservoir_Rowan.rvh
copy model\Reservoir_Esox.rvh %filename%\Reservoir_Esox.rvh
copy model\Reservoir_Kakabi.rvh %filename%\Reservoir_Kakabi.rvh
copy model\Reservoir_Otuka.rvh %filename%\Reservoir_Otuka.rvh
copy model\Reservoir_WhiteOtter.rvh %filename%\Reservoir_WhiteOtter.rvh
copy model\Reservoir_Turtle.rvh %filename%\Reservoir_Turtle.rvh
copy model\Reservoir_Finlay.rvh %filename%\Reservoir_Finlay.rvh
copy model\Reservoir_LittleTurtle.rvh %filename%\Reservoir_LittleTurtle.rvh
copy model\Reservoir_Marmion.rvh %filename%\Reservoir_Marmion.rvh
copy model\Reservoir_Sapawe.rvh %filename%\Reservoir_Sapawe.rvh
copy model\Reservoir_Crooked.rvh %filename%\Reservoir_Crooked.rvh
copy model\Reservoir_LML.rvh %filename%\Reservoir_LML.rvh
copy model\Reservoir_Quetico.rvh %filename%\Reservoir_Quetico.rvh
copy model\Reservoir_Pickerel.rvh %filename%\Reservoir_Pickerel.rvh
copy model\Reservoir_Sturgeon.rvh %filename%\Reservoir_Sturgeon.rvh
copy model\Reservoir_Kawnipi.rvh %filename%\Reservoir_Kawnipi.rvh
copy model\Reservoir_Pelican.rvh %filename%\Reservoir_Pelican.rvh
copy model\Reservoir_Saganaga.rvh %filename%\Reservoir_Saganaga.rvh
copy model\Reservoir_Basswood.rvh %filename%\Reservoir_Basswood.rvh
copy model\Reservoir_Vermillion.rvh %filename%\Reservoir_Vermillion.rvh
copy model\Reservoir_Garden.rvh %filename%\Reservoir_Garden.rvh
copy model\Reservoir_One.rvh %filename%\Reservoir_One.rvh
copy model\Reservoir_Seine.rvh %filename%\Reservoir_Seine.rvh